Long Sticky Nav — mosaik 2.3.1 documentation

# Long Sticky Nav

This section demonstrates how the ‘sticky_navigation’ setting behaves when the menu is very long. When this section is selected, it will make the menu and the main area scroll when you are at the top of the page.

## Example Menu 1

Just a place holder...

## Example Menu 2

Just a place holder...

## Example Menu 3

Just a place holder...

## Example Menu 4

Just a place holder...

## Example Menu 5

Just a place holder...

## Example Menu 6

Just a place holder...

## Example Menu 7

Just a place holder...

## Example Menu 8

Just a place holder...

## Example Menu 9

Just a place holder...

## Example Menu 10

Just a place holder...

## Example Menu 11

Just a place holder...

## Example Menu 12

Just a place holder...

## Example Menu 13

Just a place holder...

## Example Menu 14

Just a place holder...

## Example Menu 15

Just a place holder...

## Example Menu 16

Just a place holder...

## Example Menu 17

Just a place holder...

## Example Menu 18

Just a place holder...

## Example Menu 19

Just a place holder...

## Example Menu 20

Just a place holder...

## Example Submenu 1

Just a place holder...

### Submenu 1

Just a place holder...

#### Subsubmenu 1

Just a place holder...

#### Subsubmenu 2

Just a place holder...

### Submenu 2

Just a place holder...

#### Subsubmenu 1

Just a place holder...

### Submenu 3

Just a place holder...

### Submenu 4

Just a place holder...

### Submenu 5

Just a place holder...

## Example Submenu 2

Just a place holder...

### Submenu 1

Just a place holder...

#### Subsubmenu 1

Just a place holder...

### Submenu 2

Just a place holder...

#### Subsubmenu 1

Just a place holder...

### Submenu 3

Just a place holder...

### Submenu 4

Just a place holder...

### Submenu 5

Just a place holder...